#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COMPARE_LESS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COMPARE_LESS_HPP_INCLUDED

#include <nt2/reduction/include/functions/scalar/compare_less.hpp>

#endif
